# BitBox02 python API

This repository contains two packages

* u2fhid
* bitbox02

## u2fhid

This is a small package that contains read/write primitives for u2fhid devices such as the
bitbox02.

## bitbox02

In this folder is the Python API for communicating with the BitBox02 device.

The folder `generated` contains files generated by `python-protobuf`. Regenerate with `make`.
